pub unsafe fn atomic_load_u32_acquire(addr: *mut u32) -> u32Expand description
Performs an atomic acquire (load, or read) of a u32 from addr.
You can use this to read the sequence or lock value.
Safety
addr must point to a valid address and be 4-byte aligned.